==> ntch-1.0.2.2.tgz: ntch-1.0.2.2/nce/nc_update_readcnt_db.php <==
<?php
/*
 nce (ntch cloud environment.)
 name: nc_update_readcnt_db.php
 author: Akira Ohta (akohta001.gmail.com)
 date: 2013-apr-14th
 description:
 License: GPLv3
 */
include_once "account.php";
include_once "preference.php";
include_once "database.php";
include_once "log.php";
include_once "http_util.php";
include_once "error_code.php";

$user_id = $_POST['user'];
$hashed_passwd = $_POST['hashed_passwd'];
$board_name = $_POST['board_name'];
$dat_name = $_POST['dat_name'];
$res_number = $_POST['res_number'];
$record_type = $_POST['record_type'];

//--- authorization ---
$user = chk_passwd( $user_id, $hashed_passwd);
if(FALSE === $user){
	echo $ERROR_MSG;
	exit;
}

//--- parameter check start ---
if(!chk_param($board_name) || !chk_param($dat_name) ||
	!chk_param($res_number) || !chk_param($record_type)){
	echo ERROR303;
	exit;
}

if(!is_numeric($record_type)){
	echo ERROR303;
	exit;
}

if(1 != $record_type && 4 != $record_type){
	echo ERROR304;
	exit;
}

//--- parameter check end ---

$table_name = TABLE_PREFIX."tbl{$user->home_dir}";

$query1 = <<< QUERY1
select id from $table_name 
 where record_type="{$record_type}" and 
 board_name='{$board_name}' and 
  dat_name='{$dat_name}'
QUERY1;

$query2 = <<< QUERY2
insert into  $table_name 
	 (record_type, res_number, dat_name, board_name) 
	 values ('{$record_type}', '{$res_number}', "{$dat_name}", "{$board_name}")
QUERY2;

$query3 = <<< QUERY3
update $table_name 
	set res_number="{$res_number}" 
	where record_type="{$record_type}" and 
		board_name="{$board_name}" and 
		dat_name='{$dat_name}' 
QUERY3;

try{
	$db->open();
	$result = $db->execute($query1);
	if(!$result || 0 == $result->num_rows){
		$result = $db->execute($query2);
		if(!$result){
			echo ERROR501;
			exit;
		}
	}else{
		$result = $db->execute($query3);
		if(!$result){
			echo ERROR502;
			exit;
		}
	}
	$db->close();
}catch(Exception $e){
	$error = __FILE__."(".__LINE__.
		") An error occured during update a record.";
	nc_logging($error, $e);
	echo ERROR500;
	exit;
}

echo SUCCESS100;

?>

==> ntch-1.0.2.3.tgz: ntch-1.0.2.3/nce/nc_update_readcnt_db.php <==
<?php
/*
 nce (ntch cloud environment.)
 name: nc_update_readcnt_db.php
 author: Akira Ohta (akohta001.gmail.com)
 date: 2013-apr-14th
 description:
 License: GPLv3
 */
include_once "account.php";
include_once "preference.php";
include_once "database.php";
include_once "log.php";
include_once "http_util.php";
include_once "error_code.php";

$user_id = $_POST['user'];
$token = $_POST['token'];
$board_name = $_POST['board_name'];
$dat_name = $_POST['dat_name'];
$res_number = $_POST['res_number'];

//--- authorization ---
$user = chk_passwd( $user_id, $token);
if(FALSE === $user){
	echo $ERROR_MSG;
	exit;
}

//--- parameter check start ---
if(!chk_param($board_name) || !chk_param($dat_name) ||
	!chk_param($res_number)){
	echo ERROR303;
	exit;
}

//--- parameter check end ---

$table_name = TABLE_PREFIX."tbl{$user->home_dir}";

$query1 = <<< QUERY1
select id from $table_name 
 where record_type=1 and 
 board_name='{$board_name}' and 
  dat_name='{$dat_name}'
QUERY1;

$query2 = <<< QUERY2
insert into  $table_name 
	 (record_type, res_number, dat_name, board_name) 
	 values (1, '{$res_number}', "{$dat_name}", "{$board_name}")
QUERY2;

$query3 = <<< QUERY3
update $table_name 
	set res_number="{$res_number}" 
	where record_type=1 and 
		board_name="{$board_name}" and 
		dat_name='{$dat_name}' 
QUERY3;

try{
	$db->open();
	$result = $db->execute($query1);
	if(!$result || 0 == $result->num_rows){
		$result = $db->execute($query2);
		if(!$result){
			echo ERROR501;
			exit;
		}
	}else{
		$result = $db->execute($query3);
		if(!$result){
			echo ERROR502;
			exit;
		}
	}
	$db->close();
}catch(Exception $e){
	$error = __FILE__."(".__LINE__.
		") An error occured during update a record.";
	nc_logging($error, $e);
	echo ERROR500;
	exit;
}

echo SUCCESS100;

?>
